## Product details

Lysol All-Purpose Cleaner eliminates viruses, bacteria, soap scum, and tough grease. From kitchens to bathrooms to common household areas, Lysol All Purpose Cleaner helps achieve fresh, healthy surfaces. Cutting through tough grease and soap scum, it kills 99.9% of germs to help provide peace of mind for busy families. Lysol All-Purpose Cleaner provides long lasting freshness and can be used on hard, non-porous surfaces in the kitchen, bathroom and other areas of the home.
ALL PURPOSE CLEANER KILLS 99.9% OF VIRUSES & BACTERIA: Lysol All-Purpose Cleaner eliminates viruses and bacteria including COVID-19 Virus* (*Kills SARS-CoV-2 on hard, non-porous surfaces in 2 minutes), EPA Reg #777-66.
KILLS GERMS FOR A DEEP CLEAN: this disinfecting spray kills 99.9% of germs, eliminates soap scum and cuts through tough grease & grime.
USE ON MULTIPLE SURFACES: This all-purpose cleaner can be used on hard, non-porous surfaces including the kitchen, bathroom and other areas of home.
DEODORIZES AND SANITIZES HARD SURFACES: This all purpose cleaner eliminates odor causing bacteria and leaves a fresh mango and hibiscus scent after use.
LEADERS IN DISINFECTION: Looking for some of our other great household disinfectant cleaning products. Try Lysol Disinfectant Cleaning Wipes, Lysol All Purpose Cleaners, and Lysol Bathroom Cleaners (packaging may vary).
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Ingredient properties
Antibacterial
Product net content parent
32 Fluid Ounces
Scent
Fruity
Cleanser form
Liquids
More details
Directions

## Instructions
Directions For Use: It is violation of Federal Law to use this product in a manner inconsistent with its labeling. To Operate: Turn nozzle to desired position: To Refill: Remove trigger sprayer. Pour in product from refill container and replace trigger. To Clean/Deodorize: Spray surface until thoroughly wet. Wipe with a clean cloth or sponge. No rinsing required. To Clean Soap Scum and Greasy Soil: Allow product to sit to penetrate soil before wiping clean. Repeat if necessary. To Sanitize/Disinfect: Pre-clean surface. Spray surface until thoroughly wet. To Sanitize: Leave for 10 seconds before wiping. To Disinfect: Leave for 2 minutes before wiping. Rinse all food contact surfaces with water after use. Does not harm most kitchen, bathroom surfaces. On painted surfaces, test a small inconspicuous area first. Do not use on eating/cooking utensils, glasses/dishes or cookware, unfinished, oiled or waxed wood floors. This product is not recommended for use on natural marble, brass, acrylic plastics, or unfinished wood surfaces. Rinse bathtub/shower surfaces with water after using product. Storage and Disposal: Store in areas inaccessible to children. Keep securely close. Refillable container. Do not reuse or refill except as described in the directions for use. Refill trigger bottle only with this product. If not refilling, discard in trash or offer for recycle.
Fabric Care Instructions
N/A;
## Warranty

Warranty information
1

Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
More details
## Ingredients

Ingredients
Active Ingredient: Alkyl (67% C12, 25% C14, 7% C16, 1% C8-C10-C18), Dimethyl Benzyl Ammonium Chloride (0.0216%). Other Ingredients: 99.8924%, Total: 100.00%.
